/*
 * defaults
 */
html,
body,
#container{
	height: 100%;
	min-height: 100%;
}
textarea.fullscreen{
	width: 600px;
	height: 300px;
}
div.fullscreen-container{
	position: relative;
}
a.fullscreen{
	display: block;
	position: absolute;
	width: 21px;
	height: 20px;
	border: 1px solid #dadada;
	border-radius: 2px;
	top: 2px;
	cursor: pointer;
	left: 80px;
	background: #fff url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABUAAAAoCAIAAACekSayAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAyJpVFh0WE1MOmNvbS5hZG9iZS54bXAAAAAAADw/eHBhY2tldCBiZWdpbj0i77u/IiBpZD0iVzVNME1wQ2VoaUh6cmVTek5UY3prYzlkIj8+IDx4OnhtcG1ldGEgeG1sbnM6eD0iYWRvYmU6bnM6bWV0YS8iIHg6eG1wdGs9IkFkb2JlIFhNUCBDb3JlIDUuMC1jMDYwIDYxLjEzNDc3NywgMjAxMC8wMi8xMi0xNzozMjowMCAgICAgICAgIj4gPHJkZjpSREYgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIj4gPHJkZjpEZXNjcmlwdGlvbiByZGY6YWJvdXQ9IiIgeG1sbnM6eG1wPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvIiB4bWxuczp4bXBNTT0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL21tLyIgeG1sbnM6c3RSZWY9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC9zVHlwZS9SZXNvdXJjZVJlZiMiIHhtcDpDcmVhdG9yVG9vbD0iQWRvYmUgUGhvdG9zaG9wIENTNSBNYWNpbnRvc2giIHhtcE1NOkluc3RhbmNlSUQ9InhtcC5paWQ6QzBGOTc5MEVFMjc5MTFFMUIwNkM5MTBCRUI0RUI0NkIiIHhtcE1NOkRvY3VtZW50SUQ9InhtcC5kaWQ6QzBGOTc5MEZFMjc5MTFFMUIwNkM5MTBCRUI0RUI0NkIiPiA8eG1wTU06RGVyaXZlZEZyb20gc3RSZWY6aW5zdGFuY2VJRD0ieG1wLmlpZDpDMEY5NzkwQ0UyNzkxMUUxQjA2QzkxMEJFQjRFQjQ2QiIgc3RSZWY6ZG9jdW1lbnRJRD0ieG1wLmRpZDpDMEY5NzkwREUyNzkxMUUxQjA2QzkxMEJFQjRFQjQ2QiIvPiA8L3JkZjpEZXNjcmlwdGlvbj4gPC9yZGY6UkRGPiA8L3g6eG1wbWV0YT4gPD94cGFja2V0IGVuZD0iciI/Pt6yTsoAAAIfSURBVHja3FZLq0FRFHZcxyuRkgGZGZkrY2OPTPgDSnkUAym/QoZSTMwkDPwBYaCUoSFlQnkkb8e5X3bOfRBnXyN3DXb7HOdbj2+t9YXheV7ygkklr9mreNmD3yaTSb1el8lkcrmcYRjycj6fh8NhUXij0ejxeLrdrk6nUygU5OV4PKbIHy7sdvv5fJZKpR9Xo8CjhE6ng+TRJnghp9j6Ya1WS6vVov71es1xnFKppON/s9mAv9VqNZvNnE4nzu12ex8/HA5v8TabbTQaIbjP58Ojy+VCFj++4K+Wz+eFe6VSKZVK7Xabf2Zf8VFbtVrFpVwuq9VqMD8YDCjmDyShz41GQ6PRqFQq8IyTYv7QJPnFUOFut1ssFoFAgCK+sIgYFbjw+/1/2R/iBZmDQrr9mU6nx+MReLIq+/0+l8uh51ar9QGeeXP9eHf8o/3v9/vFYhGNZFlWmA5sNDZNbP+gP7VaDUNNXODj5XL5XT+f65/X6z2dTsLC/tKv5/qXyWSA4S6GC3xR6F82mzWZTEgeZQMvqLjY+OzFoF+QvUgkghOrfR/fbDZv8Q6HAyUg7UQigcdYLAY5va9/0WhUuKdSqVAoVCgUKPTPYDAkk0lc4vG4Xq+H8vZ6PTr9A1XI02w2QwKhBRaLhW7+4AJqgazA0+FwSKfTFHjSYSKkIEwM+I5+klFBIoRwivj4Y4A+k/hEhYPBoNvtxvz+Y/37FGAAhSKM0uU4rPgAAAAASUVORK5CYII=) top left no-repeat;
}
a.fullscreen:hover{
	background-position: 0 -20px;
	border-color: #cacaca;
}
/*
 * active
 */
div.fullscreen-container.active{
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	min-height: 100%;
	background-color: #fff;
	-webkit-transition: 0.2s;
	-moz-transition: 0.2s;
	-ms-transition: 0.2s;
	-o-transition: 0.2s;
}
div.fullscreen-container.active label{
	display: none;
}
div.fullscreen-container.active textarea.fullscreen{
	height: 95%;
	min-height: 95%;
	margin: 20px  auto 0 auto;
	font-family: Lato;
	font-size: 14px;
	line-height: 1.5em;
	display: block;
	border: 0;
	outline: none;
	border-bottom: 1px solid #dadada;
	border-top: 1px solid #dadada;
}
div.fullscreen-container.active a.fullscreen {
	position: fixed;
	top: 20px;
	left: 20px;
}

/*
	Inconsolata typeface was designed and released by Raph Levien (http://twitter.com/raphlinus) : http://www.levien.com/
	Used under a SIL Open Font License, 1.1
*/
@font-face {
	font-family: 'Inconsolata';
	font-style: normal;
	font-weight: normal;
	src:	local('Inconsolata'),
			url('/static/omblog/fonts/inconsolata.woff') format('woff');
}
/* 
The div and the text area
*/

fieldset.content div.writing{
	background-color: #fff;
	position: absolute;
	top: 0;
	left: 0;
}
fieldset.content div.writing textarea{
		width: 500px !important;
		outline: none;
		border: 0px none;
		margin: 0 auto;
		display: block;
		font-size: 18px;
		line-height: 28px;
		font-family: 'Inconsolata', sans-serif;
		font-style: normal;
	}
	div.writing label{
		display: none;
	}
fieldset.content div input,
fieldset.content div textarea#id_source_content{
	width: 97%;
	padding: 10px;
	font-size: 14px;
}
fieldset.content div textarea#id_source_content{
	height: 500px;
}
/* 
The activate and deactive links
*/
a.ajax_progress,
a.activate,
a.deactivate{
	width: 80px;
	height: 80px;
	display: inline-block;
	cursor: pointer;
}

	a.ajax_progress{
		background-color: #000;
		color: #fff;
		font-size: 11px;
		text-transform: uppercase;
		font-family: 'Helvetica Neue',
				Helvetica,
				Arial,
				'Sans Serif',
				sans-serif;
		line-height: 80px;
		text-align: center;
	}

	a.deactivate{
		display: none;
		background: transparent
				url(/static/omblog/img/deactivate.png)
				-10px -10px
				no-repeat;
	}

	a.activate{
		background: transparent
			url(/static/omblog/img/activate.png)
			-10px -10px
			no-repeat;
	}

		div.writing a.ajax_progress{
			position: fixed;
			top: 0;
			left: 100px;
			display: block;
		}

		div.writing a.deactivate{
			position: fixed;
			top: 0;
			left: 0;
			display: block;
		}

		div.writing a.activate{
			display: none;
		}
